==> Roberts2005Annotation_1.16.0.tar.gz: Roberts2005Annotation/man/Roberts2005AnnotationCHRLOC.Rd <==
\name{Roberts2005AnnotationCHRLOC}
\alias{Roberts2005AnnotationCHRLOC}
\title{Map Manufacturer IDs to Chromosomal Location}
\description{
  Roberts2005AnnotationCHRLOC is an R environment that maps manufacturer identifiers to the
  starting position of the gene. The position of a gene is
  measured as the number of base pairs.
}
\details{
  Each manufacturer identifier maps to a named vector of chromosomal locations,
  where the name indicates the chromosome. Due to inconsistencies that
  may exist at the time the environment was built, these vectors may
  contain more than one chromosome and/or location. If the chromosomal
  location is unknown, the vector will contain an \code{NA}.
  
  Chromosomal locations on both the sense and antisense strands are
  measured as the number of base pairs from the p (5' end of the sense
  strand) to q (3' end of the sense strand) arms. Chromosomal locations on the
  antisense strand have a leading "-" sign (e. g. -1234567). 

  Mappings were based on data provided by:

  Golden Path:\\url{ftp://hgdownload.cse.ucsc.edu/goldenPath/currentGenomes/}. Built: No build info available.
  
  Package built Fri Mar 16 22:29:53 2007
}
\examples{
    # Covert to a list
    xx <- as.list(Roberts2005AnnotationCHRLOC)
    # Remove probe identifiers that do not map to any CHRLOC
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # Gets the location for the first five probes
        xx[1:5]
        # Gets the first one
        xx[[1]]
    }
}
\keyword{datasets}

==> Roberts2005Annotation_2.0.1.tar.gz: Roberts2005Annotation/man/Roberts2005AnnotationCHRLOC.Rd <==
\name{Roberts2005AnnotationCHRLOC}
\alias{Roberts2005AnnotationCHRLOC}
\title{Map Manufacturer IDs to Chromosomal Location}
\description{
  Roberts2005AnnotationCHRLOC is an R environment that maps manufacturer identifiers to the
  starting position of the gene. The position of a gene is
  measured as the number of base pairs.
}
\details{
  Each manufacturer identifier maps to a named vector of chromosomal locations,
  where the name indicates the chromosome. Due to inconsistencies that
  may exist at the time the environment was built, these vectors may
  contain more than one chromosome and/or location. If the chromosomal
  location is unknown, the vector will contain an \code{NA}.
  
  Chromosomal locations on both the sense and antisense strands are
  measured as the number of base pairs from the p (5' end of the sense
  strand) to q (3' end of the sense strand) arms. Chromosomal locations on the
  antisense strand have a leading "-" sign (e. g. -1234567). 

  Since some genes have multiple start sites, this field can map to 
  multiple locations. 

  Mappings were based on data provided by:

  Golden Path:\\url{ftp://hgdownload.cse.ucsc.edu/goldenPath/currentGenomes/}. Built: No build info available.
  
  Package built Fri Aug 24 22:29:53 2007
}
\examples{
    # Covert to a list
    xx <- as.list(Roberts2005AnnotationCHRLOC)
    # Remove probe identifiers that do not map to any CHRLOC
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # Gets the location for the first five probes
        xx[1:5]
        # Gets the first one
        xx[[1]]
    }
}
\keyword{datasets}
